@@ -11,7 +11,7 @@ import scipy.integrate as si
 from .tools import find_intersections
 from ..constants import Cp_d, epsilon, kappa, Lv, P0, Rd
 from ..package_tools import Exporter
-from ..units import atleast_1d, concatenate, units
+from ..units import atleast_1d, check_units, concatenate, units
 
 exporter = Exporter(globals())
 
@@ -19,6 +19,7 @@ sat_pressure_0c = 6.112 * units.millibar
 
 
 @exporter.export
+@check_units('[pressure]', '[temperature]')
 def potential_temperature(pressure, temperature):
     r"""Calculate the potential temperature.
 
@@ -58,6 +59,7 @@ def potential_temperature(pressure, temperature):
 
 
 @exporter.export
+@check_units('[pressure]', '[temperature]')
 def dry_lapse(pressure, temperature):
     r"""Calculate the temperature at a level assuming only dry processes.
 
@@ -88,6 +90,7 @@ def dry_lapse(pressure, temperature):
 
 
 @exporter.export
+@check_units('[pressure]', '[temperature]')
 def moist_lapse(pressure, temperature):
     r"""Calculate the temperature at a level assuming liquid saturation processes.
 
@@ -121,12 +124,7 @@ def moist_lapse(pressure, temperature):
     .. math:: \frac{dT}{dP} = \frac{1}{P} \frac{R_d T + L_v r_s}
                                 {C_{pd} + \frac{L_v^2 r_s \epsilon}{R_d T^2}}
 
-    This equation comes from [1]_.
-
-    References
-    ----------
-    .. [1] Bakhshaii, A. and R. Stull, 2013: Saturated Pseudoadiabats--A
-           Noniterative Approximation. J. Appl. Meteor. Clim., 52, 5-15.
+    This equation comes from [Bakhshaii2013]_.
     """
     def dt(t, p):
         t = units.Quantity(t, temperature.units)
@@ -140,6 +138,7 @@ def moist_lapse(pressure, temperature):
 
 
 @exporter.export
+@check_units('[pressure]', '[temperature]', '[temperature]')
 def lcl(pressure, temperature, dewpt, max_iters=50, eps=1e-2):
     r"""Calculate the lifted condensation level (LCL) using from the starting point.
 
@@ -157,8 +156,8 @@ def lcl(pressure, temperature, dewpt, max_iters=50, eps=1e-2):
 
     Returns
     -------
-    `pint.Quantity`
-        The LCL
+    `(pint.Quantity, pint.Quantity)`
+        The LCL pressure and temperature
 
     Other Parameters
     ----------------
@@ -192,10 +191,16 @@ def lcl(pressure, temperature, dewpt, max_iters=50, eps=1e-2):
             break
         p = new_p
         max_iters -= 1
-    return new_p
+
+    else:
+        # We have not converged
+        raise RuntimeError('LCL calculation has not converged.')
+
+    return new_p, td
 
 
 @exporter.export
+@check_units('[pressure]', '[temperature]', '[temperature]')
 def lfc(pressure, temperature, dewpt):
     r"""Calculate the level of free convection (LFC).
 
@@ -221,11 +226,56 @@ def lfc(pressure, temperature, dewpt):
     parcel_profile
     """
     ideal_profile = parcel_profile(pressure, temperature[0], dewpt[0]).to('degC')
-    x, y = find_intersections(pressure, ideal_profile, temperature)
-    return x[0], y[0]
+
+    # The parcel profile and data have the same first data point, so we ignore
+    # that point to get the real first intersection for the LFC calculation.
+    x, y = find_intersections(pressure[1:], ideal_profile[1:], temperature[1:],
+                              direction='increasing')
+    if len(x) == 0:
+        return None, None
+    else:
+        return x[0], y[0]
 
 
 @exporter.export
+@check_units('[pressure]', '[temperature]', '[temperature]')
+def el(pressure, temperature, dewpt):
+    r"""Calculate the equilibrium level.
+
+    This works by finding the last intersection of the ideal parcel path and
+    the measured environmental temperature. If there is one or fewer intersections, there is
+    no equilibrium level.
+
+    Parameters
+    ----------
+    pressure : `pint.Quantity`
+        The atmospheric pressure
+    temperature : `pint.Quantity`
+        The temperature at the levels given by `pressure`
+    dewpt : `pint.Quantity`
+        The dew point at the levels given by `pressure`
+
+    Returns
+    -------
+    `pint.Quantity, pint.Quantity`
+        The EL pressure and temperature
+
+    See Also
+    --------
+    parcel_profile
+    """
+    ideal_profile = parcel_profile(pressure, temperature[0], dewpt[0]).to('degC')
+    x, y = find_intersections(pressure[1:], ideal_profile[1:], temperature[1:])
+
+    # If there is only one intersection, it's the LFC and we return None.
+    if len(x) <= 1:
+        return None, None
+    else:
+        return x[-1], y[-1]
+
+
+@exporter.export
+@check_units('[pressure]', '[temperature]', '[temperature]')
 def parcel_profile(pressure, temperature, dewpt):
     r"""Calculate the profile a parcel takes through the atmosphere.
 
@@ -253,7 +303,7 @@ def parcel_profile(pressure, temperature, dewpt):
     lcl, moist_lapse, dry_lapse
     """
     # Find the LCL
-    l = lcl(pressure[0], temperature, dewpt).to(pressure.units)
+    l = lcl(pressure[0], temperature, dewpt)[0].to(pressure.units)
 
     # Find the dry adiabatic profile, *including* the LCL. We need >= the LCL in case the
     # LCL is included in the levels. It's slightly redundant in that case, but simplifies
@@ -270,6 +320,7 @@ def parcel_profile(pressure, temperature, dewpt):
 
 
 @exporter.export
+@check_units('[pressure]', '[dimensionless]')
 def vapor_pressure(pressure, mixing):
     r"""Calculate water vapor (partial) pressure.
 
@@ -292,15 +343,10 @@ def vapor_pressure(pressure, mixing):
     Notes
     -----
     This function is a straightforward implementation of the equation given in many places,
-    such as [2]_:
+    such as [Hobbs1977]_ pg.71:
 
     .. math:: e = p \frac{r}{r + \epsilon}
 
-    References
-    ----------
-    .. [2] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
-           Survey. 71.
-
     See Also
     --------
     saturation_vapor_pressure, dewpoint
@@ -309,6 +355,7 @@ def vapor_pressure(pressure, mixing):
 
 
 @exporter.export
+@check_units('[temperature]')
 def saturation_vapor_pressure(temperature):
     r"""Calculate the saturation water vapor (partial) pressure.
 
@@ -331,14 +378,10 @@ def saturation_vapor_pressure(temperature):
     Instead of temperature, dewpoint may be used in order to calculate
     the actual (ambient) water vapor (partial) pressure.
 
-    The formula used is that from Bolton 1980 [3]_ for T in degrees Celsius:
+    The formula used is that from [Bolton1980]_ for T in degrees Celsius:
 
     .. math:: 6.112 e^\frac{17.67T}{T + 243.5}
 
-    References
-    ----------
-    .. [3] Bolton, D., 1980: The Computation of Equivalent Potential
-           Temperature. Mon. Wea. Rev., 108, 1046-1053.
     """
     # Converted from original in terms of C to use kelvin. Using raw absolute values of C in
     # a formula plays havoc with units support.
@@ -347,6 +390,7 @@ def saturation_vapor_pressure(temperature):
 
 
 @exporter.export
+@check_units('[temperature]', '[dimensionless]')
 def dewpoint_rh(temperature, rh):
     r"""Calculate the ambient dewpoint given air temperature and relative humidity.
 
@@ -370,6 +414,7 @@ def dewpoint_rh(temperature, rh):
 
 
 @exporter.export
+@check_units('[pressure]')
 def dewpoint(e):
     r"""Calculate the ambient dewpoint given the vapor pressure.
 
@@ -389,22 +434,19 @@ def dewpoint(e):
 
     Notes
     -----
-    This function inverts the Bolton 1980 [4]_ formula for saturation vapor
+    This function inverts the [Bolton1980]_ formula for saturation vapor
     pressure to instead calculate the temperature. This yield the following
     formula for dewpoint in degrees Celsius:
 
     .. math:: T = \frac{243.5 log(e / 6.112)}{17.67 - log(e / 6.112)}
 
-    References
-    ----------
-    .. [4] Bolton, D., 1980: The Computation of Equivalent Potential
-           Temperature. Mon. Wea. Rev., 108, 1046-1053.
     """
     val = np.log(e / sat_pressure_0c)
     return 0. * units.degC + 243.5 * units.delta_degC * val / (17.67 - val)
 
 
 @exporter.export
+@check_units('[pressure]', '[pressure]', '[dimensionless]')
 def mixing_ratio(part_press, tot_press, molecular_weight_ratio=epsilon):
     r"""Calculate the mixing ratio of a gas.
 
@@ -431,15 +473,10 @@ def mixing_ratio(part_press, tot_press, molecular_weight_ratio=epsilon):
     Notes
     -----
     This function is a straightforward implementation of the equation given in many places,
-    such as [5]_:
+    such as [Hobbs1977]_ pg.73:
 
     .. math:: r = \epsilon \frac{e}{p - e}
 
-    References
-    ----------
-    .. [5] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
-           Survey. 73.
-
     See Also
     --------
     saturation_mixing_ratio, vapor_pressure
@@ -448,11 +485,12 @@ def mixing_ratio(part_press, tot_press, molecular_weight_ratio=epsilon):
 
 
 @exporter.export
+@check_units('[pressure]', '[temperature]')
 def saturation_mixing_ratio(tot_press, temperature):
     r"""Calculate the saturation mixing ratio of water vapor.
 
     This calculation is given total pressure and the temperature. The implementation
-    uses the formula outlined in [6]_.
+    uses the formula outlined in [Hobbs1977]_ pg.73.
 
     Parameters
     ----------
@@ -465,21 +503,17 @@ def saturation_mixing_ratio(tot_press, temperature):
     -------
     `pint.Quantity`
         The saturation mixing ratio, dimensionless
-
-    References
-    ----------
-    .. [6] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
-           Survey. 73.
     """
     return mixing_ratio(saturation_vapor_pressure(temperature), tot_press)
 
 
 @exporter.export
+@check_units('[pressure]', '[temperature]')
 def equivalent_potential_temperature(pressure, temperature):
     r"""Calculate equivalent potential temperature.
 
     This calculation must be given an air parcel's pressure and temperature.
-    The implementation uses the formula outlined in [7]_.
+    The implementation uses the formula outlined in [Hobbs1977]_ pg.78-79.
 
     Parameters
     ----------
@@ -497,11 +531,210 @@ def equivalent_potential_temperature(pressure, temperature):
     -----
     .. math:: \Theta_e = \Theta e^\frac{L_v r_s}{C_{pd} T}
 
-    References
-    ----------
-    .. [7] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
-           Survey. 78-79.
     """
     pottemp = potential_temperature(pressure, temperature)
     smixr = saturation_mixing_ratio(pressure, temperature)
     return pottemp * np.exp(Lv * smixr / (Cp_d * temperature))
+
+
+@exporter.export
+@check_units('[temperature]', '[dimensionless]', '[dimensionless]')
+def virtual_temperature(temperature, mixing, molecular_weight_ratio=epsilon):
+    r"""Calculate virtual temperature.
+
+    This calculation must be given an air parcel's temperature and mixing ratio.
+    The implementation uses the formula outlined in [Hobbs2006] pg.80.
+
+    Parameters
+    ----------
+    temperature: `pint.Quantity`
+        The temperature
+    mixing : `pint.Quantity`
+        dimensionless mass mixing ratio
+    molecular_weight_ratio : `pint.Quantity` or float, optional
+        The ratio of the molecular weight of the constituent gas to that assumed
+        for air. Defaults to the ratio for water vapor to dry air
+        (:math:`\epsilon\approx0.622`).
+
+    Returns
+    -------
+    `pint.Quantity`
+        The corresponding virtual temperature of the parcel
+
+    Notes
+    -----
+    .. math:: T_v = T \frac{\text{w} + \epsilon}{\epsilon\,(1 + \text{w})}
+    """
+    return temperature * ((mixing + molecular_weight_ratio) /
+                          (molecular_weight_ratio * (1 + mixing)))
+
+
+@exporter.export
+@check_units('[pressure]', '[temperature]', '[dimensionless]', '[dimensionless]')
+def virtual_potential_temperature(pressure, temperature, mixing,
+                                  molecular_weight_ratio=epsilon):
+    r"""Calculate virtual potential temperature.
+
+    This calculation must be given an air parcel's pressure, temperature, and mixing ratio.
+    The implementation uses the formula outlined in [Markowski2010] pg.13.
+
+    Parameters
+    ----------
+    pressure: `pint.Quantity`
+        Total atmospheric pressure
+    temperature: `pint.Quantity`
+        The temperature
+    mixing : `pint.Quantity`
+        dimensionless mass mixing ratio
+    molecular_weight_ratio : `pint.Quantity` or float, optional
+        The ratio of the molecular weight of the constituent gas to that assumed
+        for air. Defaults to the ratio for water vapor to dry air
+        (:math:`\epsilon\approx0.622`).
+
+    Returns
+    -------
+    `pint.Quantity`
+        The corresponding virtual potential temperature of the parcel
+
+    Notes
+    -----
+    .. math:: \Theta_v = \Theta \frac{\text{w} + \epsilon}{\epsilon\,(1 + \text{w})}
+    """
+    pottemp = potential_temperature(pressure, temperature)
+    return virtual_temperature(pottemp, mixing, molecular_weight_ratio)
+
+
+@exporter.export
+@check_units('[pressure]', '[temperature]', '[dimensionless]', '[dimensionless]')
+def density(pressure, temperature, mixing, molecular_weight_ratio=epsilon):
+    r"""Calculate density.
+
+    This calculation must be given an air parcel's pressure, temperature, and mixing ratio.
+    The implementation uses the formula outlined in [Hobbs2006] pg.67.
+
+    Parameters
+    ----------
+    temperature: `pint.Quantity`
+        The temperature
+    pressure: `pint.Quantity`
+        Total atmospheric pressure
+    mixing : `pint.Quantity`
+        dimensionless mass mixing ratio
+    molecular_weight_ratio : `pint.Quantity` or float, optional
+        The ratio of the molecular weight of the constituent gas to that assumed
+        for air. Defaults to the ratio for water vapor to dry air
+        (:math:`\epsilon\approx0.622`).
+
+    Returns
+    -------
+    `pint.Quantity`
+        The corresponding density of the parcel
+
+    Notes
+    -----
+    .. math:: \rho = \frac{p}{R_dT_v}
+    """
+    virttemp = virtual_temperature(temperature, mixing, molecular_weight_ratio)
+    return (pressure / (Rd * virttemp)).to(units.kilogram / units.meter ** 3)
+
+
+@exporter.export
+@check_units('[temperature]', '[temperature]', '[pressure]')
+def relative_humidity_wet_psychrometric(dry_bulb_temperature, web_bulb_temperature,
+                                        pressure, **kwargs):
+    r"""Calculate the relative humidity with wet bulb and dry bulb temperatures.
+
+    Parameters
+    ----------
+    dry_bulb_temperature: `pint.Quantity`
+        Dry bulb temperature
+    web_bulb_temperature: `pint.Quantity`
+        Wet bulb temperature
+    pressure: `pint.Quantity`
+        Total atmospheric pressure
+
+    Returns
+    -------
+    `pint.Quantity`
+        Relative humidity
+
+    Notes
+    -----
+    .. math:: RH = 100 \frac{e}{e_s}
+
+    * :math:`RH` is relative humidity
+    * :math:`e` is vapor pressure from the wet psychrometric calculation
+    * :math:`e_s` is the saturation vapor pressure
+
+    References
+    ----------
+    .. [10] WMO GUIDE TO METEOROLOGICAL INSTRUMENTS AND METHODS OF OBSERVATION WMO-No.8
+       (2008 edition, Updated in 2010) : PART 4
+       https://www.wmo.int/pages/prog/www/IMOP/CIMO-Guide.html
+
+    .. [11] Fan, Jinpeng. "Determination of the psychrometer coefficient A of the WMO
+       reference psychrometer by comparison with a standard gravimetric hygrometer."
+       Journal of Atmospheric and Oceanic Technology 4.1 (1987): 239-244.
+
+    See Also
+    --------
+    psychrometric_vapor_pressure_wet, saturation_vapor_pressure
+    """
+    return (100 * units.percent * psychrometric_vapor_pressure_wet(dry_bulb_temperature,
+            web_bulb_temperature, pressure, **kwargs) /
+            saturation_vapor_pressure(dry_bulb_temperature))
+
+
+@exporter.export
+@check_units('[temperature]', '[temperature]', '[pressure]')
+def psychrometric_vapor_pressure_wet(dry_bulb_temperature, wet_bulb_temperature, pressure,
+                                     psychrometer_coefficient=6.21e-4 / units.kelvin):
+    r"""Calculate the vapor pressure with wet bulb and dry bulb temperatures.
+
+    Parameters
+    ----------
+    dry_bulb_temperature: `pint.Quantity`
+        Dry bulb temperature
+    wet_bulb_temperature: `pint.Quantity`
+        Wet bulb temperature
+    pressure: `pint.Quantity`
+        Total atmospheric pressure
+    psychrometer_coefficient: `pint.Quantity`
+        Psychrometer coefficient
+
+    Returns
+    -------
+    `pint.Quantity`
+        Vapor pressure
+
+    Notes
+    -----
+    .. math:: e' = e'_w(T_w) - A p (T - T_w)
+
+    * :math:`e'` is vapor pressure
+    * :math:`e'_w(T_w)` is the saturation vapor pressure with respect to water at temperature
+      :math:`T_w`
+    * :math:`p` is the pressure of the wet bulb
+    * :math:`T` is the temperature of the dry bulb
+    * :math:`T_w` is the temperature of the wet bulb
+    * :math:`A` is the psychrometer coefficient
+
+    Psychrometer coefficient depends on the specific instrument being used and the ventilation
+    of the instrument.
+
+    References
+    ----------
+    .. [12] WMO GUIDE TO METEOROLOGICAL INSTRUMENTS AND METHODS OF OBSERVATION WMO-No.8
+       (2008 edition, Updated in 2010) : PART 4
+       https://www.wmo.int/pages/prog/www/IMOP/CIMO-Guide.html
+
+    .. [13] Fan, Jinpeng. "Determination of the psychrometer coefficient A of the WMO reference
+       psychrometer by comparison with a standard gravimetric hygrometer."
+       Journal of Atmospheric and Oceanic Technology 4.1 (1987): 239-244.
+
+    See Also
+    --------
+    saturation_vapor_pressure
+    """
+    return (saturation_vapor_pressure(wet_bulb_temperature) - psychrometer_coefficient *
+            pressure * (dry_bulb_temperature - wet_bulb_temperature).to('kelvin'))
