@@ -1,20 +1,24 @@
-# Copyright (c) 2008-2015 MetPy Developers.
+# Copyright (c) 2008-2016 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
+"""Tools for working with points."""
 
 from __future__ import division
 
-import numpy as np
+import logging
 
+import numpy as np
 from scipy.spatial import cKDTree
 
-import warnings
+log = logging.getLogger(__name__)
+log.addHandler(logging.StreamHandler())  # Python 2.7 needs a handler set
+log.setLevel(logging.WARNING)
 
 
-def get_points_within_r(center_points, target_points, r, return_idx=False):
-    r"""Get all target_points within a specified radius
-    of a center point.  All data must be in same coord-
-    inate system, or you will get unpredictable results.
+def get_points_within_r(center_points, target_points, r):
+    r"""Get all target_points within a specified radius of a center point.
+
+    All data must be in same coordinate system, or you will get undetermined results.
 
     Parameters
     ----------
@@ -24,9 +28,6 @@ def get_points_within_r(center_points, target_points, r, return_idx=False):
         points from which to return if they are within r of center_points
     r: integer
         search radius around center_points to grab target_points
-    return_idx: bool
-        If true, function will return indices of winning points
-        If false (default), function will return list of winning points
 
     Returns
     -------
@@ -34,16 +35,15 @@ def get_points_within_r(center_points, target_points, r, return_idx=False):
         A list of points within r distance of, and in the same
         order as, center_points
     """
-
     tree = cKDTree(target_points)
     indices = tree.query_ball_point(center_points, r)
     return tree.data[indices].T
 
 
 def get_point_count_within_r(center_points, target_points, r):
-    r"""Get count of target points within a specified radius
-    from center points.  All data must be in same coord-
-    inate system, or you will get unpredictable results.
+    r"""Get count of target points within a specified radius from center points.
+
+    All data must be in same coordinate system, or you will get undetermined results.
 
     Parameters
     ----------
@@ -60,14 +60,13 @@ def get_point_count_within_r(center_points, target_points, r):
         A list of point counts within r distance of, and in the same
         order as, center_points
     """
-
     tree = cKDTree(target_points)
     indices = tree.query_ball_point(center_points, r)
     return np.array([len(x) for x in indices])
 
 
-def generate_grid(horiz_dim, bbox, ignore_warnings=False):
-    r"""Generate a meshgrid based on bounding box and x & y resolution
+def generate_grid(horiz_dim, bbox):
+    r"""Generate a meshgrid based on bounding box and x & y resolution.
 
     Parameters
     ----------
@@ -75,9 +74,6 @@ def generate_grid(horiz_dim, bbox, ignore_warnings=False):
         Horizontal resolution in meters
     bbox: dictionary
         Dictionary containing coordinates for corners of study area.
-    ignore_warnings: bool
-        Toggle whether or not to display warning to prevent very large
-        number of grids. Default is False.
 
     Returns
     -------
@@ -86,9 +82,8 @@ def generate_grid(horiz_dim, bbox, ignore_warnings=False):
     grid_y: (X, Y) ndarray
         Y dimension meshgrid defined by given bounding box
     """
-
-    if horiz_dim < 10000 and not ignore_warnings:
-        warnings.warn('Grids less than 10km may be slow to load at synoptic scale.')
+    if horiz_dim < 10000:
+        log.warning('Grids less than 10km may be slow to load at synoptic scale.')
 
     x_steps, y_steps = get_xy_steps(bbox, horiz_dim)
 
@@ -101,7 +96,7 @@ def generate_grid(horiz_dim, bbox, ignore_warnings=False):
 
 
 def generate_grid_coords(gx, gy):
-    r"""Calculate x,y coordinates of each grid cell
+    r"""Calculate x,y coordinates of each grid cell.
 
     Parameters
     ----------
@@ -115,12 +110,11 @@ def generate_grid_coords(gx, gy):
     (X, Y) ndarray
         List of coordinates in meshgrid
     """
-
     return np.vstack([gx.ravel(), gy.ravel()]).T
 
 
 def get_xy_range(bbox):
-    r"""Returns x and y ranges in meters based on bounding box
+    r"""Return x and y ranges in meters based on bounding box.
 
     bbox: dictionary
         dictionary containing coordinates for corners of study area
@@ -132,7 +126,6 @@ def get_xy_range(bbox):
     y_range: float
         Range in meters in y dimension.
     """
-
     x_range = bbox['east'] - bbox['west']
     y_range = bbox['north'] - bbox['south']
 
@@ -140,7 +133,7 @@ def get_xy_range(bbox):
 
 
 def get_xy_steps(bbox, h_dim):
-    r"""Return meshgrid spacing based on bounding box
+    r"""Return meshgrid spacing based on bounding box.
 
     bbox: dictionary
         Dictionary containing coordinates for corners of study area.
@@ -154,7 +147,6 @@ def get_xy_steps(bbox, h_dim):
     y_steps: (Y, ) ndarray
         Number of grids in y dimension.
     """
-
     x_range, y_range = get_xy_range(bbox)
 
     x_steps = np.ceil(x_range / h_dim)
@@ -164,8 +156,7 @@ def get_xy_steps(bbox, h_dim):
 
 
 def get_boundary_coords(x, y, spatial_pad=0):
-    r"""Return bounding box based on given x and y coordinates
-       assuming northern hemisphere.
+    r"""Return bounding box based on given x and y coordinates assuming northern hemisphere.
 
     x: numeric
         x coordinates.
@@ -180,7 +171,6 @@ def get_boundary_coords(x, y, spatial_pad=0):
     bbox: dictionary
         dictionary containing coordinates for corners of study area
     """
-
     west = np.min(x) - spatial_pad
     east = np.max(x) + spatial_pad
     north = np.max(y) + spatial_pad
