@@ -1,38 +1,40 @@
 # Copyright (c) 2008-2015 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
+"""Tools to process GINI-formatted products."""
 
-import logging
-import re
 from datetime import datetime
 try:
     from enum import Enum
 except ImportError:
     from enum34 import Enum
 from itertools import repeat
+import logging
+import re
 
 import numpy as np
-from .tools import Bits, IOBuffer, NamedStruct, zlib_decompress_all_frames
-from .cdm import Dataset, cf_to_proj
+
+from ._tools import Bits, IOBuffer, NamedStruct, zlib_decompress_all_frames
+from .cdm import cf_to_proj, Dataset
 from ..cbook import is_string_like
 from ..package_tools import Exporter
 
 exporter = Exporter(globals())
 
-log = logging.getLogger('metpy.io.gini')
+log = logging.getLogger(__name__)
 log.addHandler(logging.StreamHandler())  # Python 2.7 needs a handler set
 log.setLevel(logging.WARN)
 
 
 def _make_datetime(s):
-    r'Converts 7 bytes from a GINI file to a `datetime` instance.'
+    r"""Convert 7 bytes from a GINI file to a `datetime` instance."""
     s = bytearray(s)  # For Python 2
     year, month, day, hour, minute, second, cs = s
     return datetime(1900 + year, month, day, hour, minute, second, 10000 * cs)
 
 
 def _scaled_int(s):
-    r'Converts a 3 byte string to a signed integer value'
+    r"""Convert a 3 byte string to a signed integer value."""
     s = bytearray(s)  # For Python 2
 
     # Get leftmost bit (sign) as 1 (if 0) or -1 (if 1)
@@ -47,7 +49,7 @@ def _scaled_int(s):
 
 
 def _name_lookup(names):
-    r'Creates an io helper to convert an integer to a named value.'
+    r"""Create an io helper to convert an integer to a named value."""
     mapper = dict(zip(range(len(names)), names))
 
     def lookup(val):
@@ -56,7 +58,8 @@ def _name_lookup(names):
 
 
 class GiniProjection(Enum):
-    r'Represents projection values in GINI files'
+    r"""Represents projection values in GINI files."""
+
     mercator = 1
     lambert_conformal = 3
     polar_stereographic = 5
@@ -64,7 +67,7 @@ class GiniProjection(Enum):
 
 @exporter.export
 class GiniFile(object):
-    r'''A class that handles reading the GINI format satellite images from the NWS.
+    """A class that handles reading the GINI format satellite images from the NWS.
 
     This class attempts to decode every byte that is in a given GINI file.
 
@@ -76,7 +79,8 @@ class GiniFile(object):
     See Also
     --------
     GiniFile.to_dataset
-    '''
+    """
+
     missing = 255
     wmo_finder = re.compile('(T\w{3}\d{2})[\s\w\d]+\w*(\w{3})\r\r\n')
 
@@ -135,7 +139,7 @@ class GiniFile(object):
                            ('ur_lon', '3s', _scaled_int)], '>', 'Navigation')
 
     def __init__(self, filename):
-        r'''Create instance of `GiniFile`.
+        r"""Create an instance of `GiniFile`.
 
         Parameters
         ----------
@@ -144,8 +148,7 @@ class GiniFile(object):
             recognized with the extension ``'.gz'``, as are bzip2-ed files with
             the extension ``'.bz2'`` If `filename` is a file-like object,
             this will be read from directly.
-        '''
-
+        """
         if is_string_like(filename):
             fobj = open(filename, 'rb')
             self.filename = filename
@@ -298,7 +301,7 @@ class GiniFile(object):
         return ds
 
     def _process_wmo_header(self):
-        'Read off the WMO header from the file, if necessary.'
+        """Read off the WMO header from the file, if necessary."""
         data = self._buffer.get_next(64).decode('utf-8', 'ignore')
         match = self.wmo_finder.search(data)
         if match:
@@ -307,6 +310,7 @@ class GiniFile(object):
             self._buffer.skip(match.end())
 
     def __str__(self):
+        """Return a string representation of the product."""
         parts = [self.__class__.__name__ + ': {0.creating_entity} {0.sector_id} {0.channel}',
                  'Time: {0.datetime}', 'Size: {0.ny}x{0.nx}',
                  'Projection: {0.projection.name}',
@@ -316,7 +320,7 @@ class GiniFile(object):
 
 
 def _add_projection_coords(ds, prod_desc, proj_var, dx, dy):
-    'Helper function for adding coordinate variables (projection and lon/lat) to a dataset'
+    """Add coordinate variables (projection and lon/lat) to a dataset."""
     proj = cf_to_proj(proj_var)
 
     # Get projected location of lower left point
@@ -348,3 +352,5 @@ def _add_projection_coords(ds, prod_desc, proj_var, dx, dy):
     lat_var = ds.createVariable('lat', np.float64, dimensions=('y', 'x'), wrap_array=lat)
     lat_var.long_name = 'latitude'
     lat_var.units = 'degrees_north'
+
+    ds.img_extent = (x_var[:].min(), x_var[:].max(), y_var[:].min(), y_var[:].max())
