@@ -5,6 +5,36 @@
 
 Contains a tools for reading color tables from files, and creating instances based on a
 specific set of constraints (e.g. step size) for mapping.
+
+.. plot::
+
+   import numpy as np
+   import matplotlib.pyplot as plt
+   import metpy.plots.ctables as ctables
+
+   def plot_color_gradients(cmap_category, cmap_list, nrows):
+       fig, axes = plt.subplots(figsize=(7, 6), nrows=nrows)
+       fig.subplots_adjust(top=.93, bottom=0.01, left=0.32, right=0.99)
+       axes[0].set_title(cmap_category + ' colormaps', fontsize=14)
+
+       for ax, name in zip(axes, cmap_list):
+           ax.imshow(gradient, aspect='auto', cmap=ctables.registry.get_colortable(name))
+           pos = list(ax.get_position().bounds)
+           x_text = pos[0] - 0.01
+           y_text = pos[1] + pos[3]/2.
+           fig.text(x_text, y_text, name, va='center', ha='right', fontsize=10)
+
+       # Turn off *all* ticks & spines, not just the ones with colormaps.
+       for ax in axes:
+           ax.set_axis_off()
+
+   cmaps = list(ctables.registry.keys())
+   nrows = len(cmaps)
+   gradient = np.linspace(0, 1, 256)
+   gradient = np.vstack((gradient, gradient))
+
+   plot_color_gradients('MetPy', cmaps, nrows)
+   plt.show()
 """
 
 from __future__ import division
@@ -163,6 +193,34 @@ class ColortableRegistry(dict):
         boundaries = arange(start, start + step * num_steps, step)
         return self.get_with_boundaries(name, boundaries)
 
+    def get_with_range(self, name, start, end):
+        r"""Get a color table from the registry with a corresponding norm.
+
+        Builds a `matplotlib.colors.BoundaryNorm` using `start`, `end`, and
+        the number of colors, based on the color table obtained from `name`.
+
+        Parameters
+        ----------
+        name : str
+            The name under which the color table will be stored
+        start : float
+            The starting boundary
+        end : float
+            The ending boundary
+
+        Returns
+        -------
+        `matplotlib.colors.BoundaryNorm`, `matplotlib.colors.ListedColormap`
+            The boundary norm based on `start` and `end` with the number of colors
+            from the number of entries matching the color table, and the color table itself.
+        """
+        from numpy import linspace
+
+        # Need one more boundary than color
+        num_steps = len(self[name]) + 1
+        boundaries = linspace(start, end, num_steps)
+        return self.get_with_boundaries(name, boundaries)
+
     def get_with_boundaries(self, name, boundaries):
         r"""Get a color table from the registry with a corresponding norm.
 
